==> haskell-quickcheck-unicode-1.0.1.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-unicode
version: 1.0.1.0
id: quickcheck-unicode-1.0.1.0-FYAjRDoblHzKg5baOiDKeL
key: quickcheck-unicode-1.0.1.0-FYAjRDoblHzKg5baOiDKeL
license: BSD-2-Clause
copyright: 2014-2017 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/quickcheck-unicode
synopsis: Generator and shrink functions for testing
          Unicode-related software.
description:
    Generator and shrink functions for testing
    Unicode-related software.
category: Testing, Text
abi: 6b2e3890bee124b4852b8386e2740f91
exposed: True
exposed-modules:
    Test.QuickCheck.Unicode
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-unicode-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-unicode-1.0.1.0
hs-libraries: HSquickcheck-unicode-1.0.1.0-FYAjRDoblHzKg5baOiDKeL
depends:
    QuickCheck-2.13.2-52gUk4jYsn5ItHsbXhjyg4 base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-unicode
version: 1.0.1.0
id: quickcheck-unicode-1.0.1.0-4tPS4GejHt0GYOg5ZW9Ydg
key: quickcheck-unicode-1.0.1.0-4tPS4GejHt0GYOg5ZW9Ydg
license: BSD-2-Clause
copyright: 2014-2017 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/quickcheck-unicode
synopsis: Generator and shrink functions for testing
          Unicode-related software.
description:
    Generator and shrink functions for testing
    Unicode-related software.
category: Testing, Text
abi: a7e694c6eaef388edfb17603fcf87964
exposed: True
exposed-modules:
    Test.QuickCheck.Unicode
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-unicode-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-unicode-1.0.1.0
hs-libraries: HSquickcheck-unicode-1.0.1.0-4tPS4GejHt0GYOg5ZW9Ydg
depends:
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
